@@ -11,7 +11,7 @@ static INIT: Once = Once::new();
 pub fn breakpoint() {
     let mut init = false;
     INIT.call_once(|| {
-        let gdb = format!("sudo ugdb --gdb=rust-gdb --pid {}", getpid());
+        let gdb = format!("sudo ugdb --layout=\"(1s-1c)\" --gdb=rust-gdb --pid {}", getpid());
         let argv = vec!["neww", &gdb];
         let argv_c = argv.iter().map(|s| s.to_string()).collect::<Vec<_>>();
         Command::new("tmux").args(&argv_c[..]).spawn().unwrap();
